<?php
/**
 * Functions which construct the theme by hooking into WordPress
 *
 * @package shark_news
 */


/*------------------------------------------------
            HEADER HOOK
------------------------------------------------*/

if ( ! function_exists( 'shark_news_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_doctype() { ?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php }
endif;
add_action( 'shark_news_doctype_action', 'shark_news_doctype', 10 );

if ( ! function_exists( 'shark_news_head' ) ) :
	/**
	 * head Codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_head() { ?>
		<head>
			<meta charset="<?php bloginfo( 'charset' ); ?>">
			<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
			<link rel="profile" href="http://gmpg.org/xfn/11">
			<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
				<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
			<?php endif; ?>
			<?php wp_head(); ?>
		</head>
	<?php }
endif;
add_action( 'shark_news_head_action', 'shark_news_head', 10 );

if ( ! function_exists( 'shark_news_body_start' ) ) :
	/**
	 * Body start codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_body_start() { ?>
		<body <?php body_class(); ?>>
		<?php do_action( 'wp_body_open' ); ?>
	<?php }
endif;
add_action( 'shark_news_body_start_action', 'shark_news_body_start', 10 );


if ( ! function_exists( 'shark_news_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_page_start() { ?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'shark-news' ); ?></a>
	<?php }
endif;
add_action( 'shark_news_page_start_action', 'shark_news_page_start', 10 );


if ( ! function_exists( 'shark_news_loader' ) ) :
	/**
	 * loader html codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_loader() { 
		if ( ! shark_news_theme_option( 'enable_loader' ) )
			return;
		
		$loader = shark_news_theme_option( 'loader_type' )
		?>
		<div id="loader">
            <div class="loader-container">
               	<?php echo shark_news_get_svg( array( 'icon' => esc_attr( $loader ) ) ); ?>
            </div>
        </div><!-- #loader -->
	<?php }
endif;
add_action( 'shark_news_page_start_action', 'shark_news_loader', 20 );

if ( ! function_exists( 'shark_news_top_bar' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_top_bar() { 
		if ( ! shark_news_theme_option( 'show_topbar_menu' ) && ! shark_news_theme_option( 'show_social_menu' ) )
			return;
		?>
		<div id="top-menu">
            <?php 
            echo shark_news_get_svg( array( 'icon' => 'up', 'class' => 'dropdown-icon' ) );
            echo shark_news_get_svg( array( 'icon' => 'down', 'class' => 'dropdown-icon' ) ); 
            ?>
            
            <div class="wrapper">
            	<?php if ( shark_news_theme_option( 'show_topbar_menu' ) && has_nav_menu( 'topbar' ) ) : ?>
	                <div class="secondary-menu">
	                	<?php  
	                	wp_nav_menu( array(
	                		'theme_location'  => 'topbar',
	                		'container' 	  => false,
	                		'menu_class'      => 'menu',
	                		'fallback_cb'     => false,
	                		'depth'           => 1,
	                	) );
	                	?>
	                </div><!-- .secondary-menu -->
	            <?php endif;

	            if ( shark_news_theme_option( 'show_social_menu' ) && has_nav_menu( 'social' ) ) : ?>
	                <div class="social-menu">
	                    <?php  
	                    $date = '';
	                    if ( shark_news_theme_option( 'show_menu_date' ) ) :
		                    $date .= '<li class="date">';
							$date .= date('D jS M Y');
			                $date .= '</li>';
		                endif;
	                	wp_nav_menu( array(
	                		'theme_location'  	=> 'social',
	                		'container' 		=> false,
	                		'menu_class'      	=> 'menu',
	                		'depth'           	=> 1,
	            			'link_before' 		=> '<span class="screen-reader-text">',
							'link_after' 		=> '</span>',
							'items_wrap' => '<ul id="%1$s" class="%2$s">' . $date . '%3$s</ul>',
	                	) );
	                	?>
	                </div><!-- .social-menu -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #top-menu -->
	<?php }
endif;
add_action( 'shark_news_page_start_action', 'shark_news_top_bar', 40 );


if ( ! function_exists( 'shark_news_header_start' ) ) :
	/**
	 * Header starts html codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_header_start() {
		$image = get_header_image() ? get_header_image() : ''; ?>
		<header id="masthead" class="site-header" style="background-image: url('<?php echo esc_url( $image ); ?>');">
	<?php }
endif;
add_action( 'shark_news_header_start_action', 'shark_news_header_start', 10 );


if ( ! function_exists( 'shark_news_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_site_branding() { 
		?>
		<div class="wrapper header-wrapper">
			<div class="site-branding">
				<?php
				// site logo
				the_custom_logo();
				?>
				<div class="site-details">
					<?php
					if ( is_front_page() && is_home() ) : ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<?php else : ?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php endif;

					$description = get_bloginfo( 'description', 'display' );
					if ( $description || is_customize_preview() ) : ?>
						<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
					<?php endif; ?>
				</div><!-- .site-details -->
			</div><!-- .site-branding -->

			<?php if ( is_active_sidebar( 'header-ads-area' ) ) : ?>
				<div class="header-ads">
					<?php dynamic_sidebar( 'header-ads-area' ); ?>
				</div>
			<?php endif; ?>
		</div><!-- .wrapper -->
	<?php }
endif;
add_action( 'shark_news_site_branding_action', 'shark_news_site_branding', 10 );


if ( ! function_exists( 'shark_news_primary_nav' ) ) :
	/**
	 * Primary nav codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_primary_nav() { ?>
		<nav id="site-navigation" class="main-navigation">
			<div class="wrapper">
				<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
	                <span class="screen-reader-text"><?php esc_html_e( 'Menu', 'shark-news' ); ?></span>
	                <svg viewBox="0 0 40 40" class="icon-menu">
	                    <g>
	                        <rect y="7" width="40" height="2"/>
	                        <rect y="19" width="40" height="2"/>
	                        <rect y="31" width="40" height="2"/>
	                    </g>
	                </svg>
	                <?php echo shark_news_get_svg( array( 'icon' => 'close' ) ); ?>
	            </button>
	            
				<?php
					$search = '';
					if ( is_active_sidebar( 'off-canvas-area' ) ) :
		                $search .= '<li class="main-navigation-off-canvas">';
		                $search .= '<a href="#" id="off-canvas-icon">';
		                $search .= shark_news_get_svg( array( 'icon' => 'half-menu' ) );
		                $search .= '</a></li>';
		            endif;

					if ( shark_news_theme_option('show_menu_search' ) ) :
						$search .= '<li class="main-navigation-search">';
						$search .= '<div id="search">' . get_search_form( $echo = false ) . '</div>';
						$search .= '<a href="#" class="search">';
						$search .= shark_news_get_svg( array( 'icon' => 'search' ) );
		                $search .= '</a></li>';
	                endif;

					wp_nav_menu( array(
						'theme_location' => 'primary',
	        			'container' => false,
	        			'menu_class' => 'menu nav-menu',
	        			'menu_id' => 'primary-menu',
	        			'fallback_cb' => 'shark_news_menu_fallback_cb',
	        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $search . '</ul>',
					) );					
				?>
			</div><!-- .wrapper -->
		</nav><!-- #site-navigation -->

		<?php if ( is_active_sidebar( 'off-canvas-area' ) ) : ?>
			<div id="off-canvas">
				<div class="off-canvas-wrapper">
					<?php 
						echo shark_news_get_svg( array( 'icon' => 'close' ) );
						dynamic_sidebar( 'off-canvas-area' ); 
					?>
				</div><!-- .off-canvas-wrapper -->
			</div><!-- #off-canvas -->
		<?php endif; ?>
	<?php }
endif;
add_action( 'shark_news_primary_nav_action', 'shark_news_primary_nav', 10 );


if ( ! function_exists( 'shark_news_header_tags_list' ) ) :
	/**
	 * Header ends codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_header_tags_list() { 
		$trending_enable = apply_filters( 'shark_news_section_status', 'enable_trending', 'trending_entire_site' );

		if ( ! $trending_enable )
            return false;

        $trending_title = shark_news_theme_option('trending_title', esc_html__( 'Trending', 'shark-news' ) );
        $tags = shark_news_theme_option('trending_content_tags' );
        $tags = ! empty( $tags ) ? get_tags( array( 'include' => $tags ) ) : get_tags();
		?>
		<div class="tags-list">
			<div class="wrapper">
				<ul>
					<li class="tags-title"><?php echo esc_html( $trending_title ); ?>:</li>
					<?php foreach ( $tags as $tag ) : ?>
						<li><a href="<?php echo esc_url( get_tag_link( $tag->term_id ) ); ?>"><?php echo '#' . esc_html( $tag->name ); ?></a></li>
					<?php endforeach; ?>
				</ul>
			</div>
		</div>
	<?php }
endif;
add_action( 'shark_news_header_ends_action', 'shark_news_header_tags_list', 10 );


if ( ! function_exists( 'shark_news_header_ends' ) ) :
	/**
	 * Header ends codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_header_ends() { ?>
		</header><!-- #masthead -->
	<?php }
endif;
add_action( 'shark_news_header_ends_action', 'shark_news_header_ends', 20 );


if ( ! function_exists( 'shark_news_site_content_start' ) ) :
	/**
	 * Site content start codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_site_content_start() { ?>
		<div id="content" class="site-content">
	<?php }
endif;
add_action( 'shark_news_site_content_start_action', 'shark_news_site_content_start', 10 );


/*------------------------------------------------
            FOOTER HOOK
------------------------------------------------*/

if ( ! function_exists( 'shark_news_site_content_ends' ) ) :
	/**
	 * Site content ends codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_site_content_ends() { ?>
		</div><!-- #content -->
	<?php }
endif;
add_action( 'shark_news_site_content_ends_action', 'shark_news_site_content_ends', 10 );


if ( ! function_exists( 'shark_news_footer_start' ) ) :
	/**
	 * Footer start codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_footer_start() { ?>
		<footer id="colophon" class="site-footer">
	<?php }
endif;
add_action( 'shark_news_footer_start_action', 'shark_news_footer_start', 10 );


if ( ! function_exists( 'shark_news_site_info' ) ) :
	/**
	 * Site info codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_site_info() { 
		$copyright = shark_news_theme_option('copyright_text');
		$poweredby = shark_news_theme_option('poweredby_text');
		?>
		<div class="site-info">
            <div class="wrapper">
            	<?php if ( ! empty( $copyright ) ) : ?>
	                <div class="copyright">
	                	<p>
	                    	<?php 
	                    	echo shark_news_santize_allow_tags( $copyright ); 
	                    	if ( function_exists( 'the_privacy_policy_link' ) ) {
								the_privacy_policy_link( ' | ' );
							}
	                    	?>
	                    </p>
	                </div><!-- .copyright -->
	            <?php endif; 

	            if ( ! empty( $copyright ) ) : ?>
	                <div class="powered-by">
	                    <p><?php printf( esc_html__( ' Shark News by %1$s Shark Themes %2$s', 'shark-news' ), '<a href="' . esc_url( 'https://sharkthemes.com/' ) . '" target="_blank">','</a>' ); ?></p>
	                </div><!-- .powered-by -->
	            <?php endif; ?>
            </div><!-- .wrapper -->    
        </div><!-- .site-info -->
	<?php }
endif;
add_action( 'shark_news_site_info_action', 'shark_news_site_info', 10 );


if ( ! function_exists( 'shark_news_footer_ends' ) ) :
	/**
	 * Footer ends codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_footer_ends() { ?>
		</footer><!-- #colophon -->
	<?php }
endif;
add_action( 'shark_news_footer_ends_action', 'shark_news_footer_ends', 10 );


if ( ! function_exists( 'shark_news_slide_to_top' ) ) :
	/**
	 * Footer ends codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_slide_to_top() { ?>
		<div class="backtotop">
            <?php echo shark_news_get_svg( array( 'icon' => 'up' ) ); ?>
        </div><!-- .backtotop -->
	<?php }
endif;
add_action( 'shark_news_footer_ends_action', 'shark_news_slide_to_top', 20 );


if ( ! function_exists( 'shark_news_page_ends' ) ) :
	/**
	 * Page ends codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_page_ends() { ?>
		</div><!-- #page -->
	<?php }
endif;
add_action( 'shark_news_page_ends_action', 'shark_news_page_ends', 10 );


if ( ! function_exists( 'shark_news_body_html_ends' ) ) :
	/**
	 * Body & Html ends codes
	 *
	 * @since Shark News 1.0.0
	 */
	function shark_news_body_html_ends() { ?>
		</body>
		</html>
	<?php }
endif;
add_action( 'shark_news_body_html_ends_action', 'shark_news_body_html_ends', 10 );

if ( ! function_exists( 'shark_news_related_posts' ) ) :
	/**
	 * three related posts
	 *
	 * @since Shark News Pro 1.0.0
	 */
	function shark_news_related_posts( $post_id ) { 
		if ( empty( $post_id ) )
			return;

		$category = get_the_category( $post_id );
		$related_category = array();
		
		foreach ( $category as $cat ) {
			array_push( $related_category, $cat->term_id );
		}

		$related_args = array(
            'post_type'         => 'post',
            'posts_per_page'    => 3,
            'cat'               => (array) $related_category,
            'ignore_sticky_posts' => true,
            'post__not_in' 		=> (array) $post_id,
            );

		$related_query = new WP_Query( $related_args );
		$title = shark_news_theme_option( 'show_related_posts_title' );
		?>

		<div id="related-posts" class="column-3">
			<?php if ( $related_query -> have_posts() ) : 

				if ( ! empty( $title ) ) : ?>
					<h2 class="section-title"><?php echo esc_html( $title ); ?></h2>
				<?php endif; ?>

				<div class="section-content">
	                <?php while ( $related_query -> have_posts() ) : $related_query -> the_post(); ?>
						<article class="hentry">
			                <div class="post-wrapper">
			                    <?php if ( has_post_thumbnail() ) : ?>
			                        <div class="featured-image">
			                            <a href="<?php the_permalink(); ?>">
			                                <?php the_post_thumbnail( 'post-thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
			                            </a>
			                            <?php the_category(); ?>
			                        </div><!-- .featured-image -->
			                    <?php endif; ?>

			                    <div class="entry-container">
			                        <header class="entry-header">
			                            <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
			                        </header>
			                    </div><!-- .entry-container -->
			                </div><!-- .post-wrapper -->
			            </article>
		            <?php endwhile; ?>
	            </div><!-- .section-content -->
	        <?php endif;
	        wp_reset_postdata(); ?>
		</div>
	<?php
	}
endif;