<?php
/**
 * Highlight Customizer Options
 *
 * @package shark_news
 */

// Add highlight section
$wp_customize->add_section( 'shark_news_highlight_section', array(
	'title'             => esc_html__( 'Headline Section','shark-news' ),
	'description'       => esc_html__( 'Headline Setting Options', 'shark-news' ),
	'panel'             => 'shark_news_theme_options_panel',
) );

// highlight menu enable setting and control.
$wp_customize->add_setting( 'shark_news_theme_options[enable_highlight]', array(
	'default'           => shark_news_theme_option('enable_highlight'),
	'sanitize_callback' => 'shark_news_sanitize_switch',
) );

$wp_customize->add_control( new Shark_News_Switch_Control( $wp_customize, 'shark_news_theme_options[enable_highlight]', array(
	'label'             => esc_html__( 'Enable Highlight', 'shark-news' ),
	'section'           => 'shark_news_highlight_section',
	'on_off_label' 		=> shark_news_show_options(),
) ) );

// highlight social menu enable setting and control.
$wp_customize->add_setting( 'shark_news_theme_options[highlight_entire_site]', array(
	'default'           => shark_news_theme_option('highlight_entire_site'),
	'sanitize_callback' => 'shark_news_sanitize_switch',
) );

$wp_customize->add_control( new Shark_News_Switch_Control( $wp_customize, 'shark_news_theme_options[highlight_entire_site]', array(
	'label'             => esc_html__( 'Show Entire Site', 'shark-news' ),
	'section'           => 'shark_news_highlight_section',
	'on_off_label' 		=> shark_news_show_options(),
) ) );

// headline title drop down chooser control and setting
$wp_customize->add_setting( 'shark_news_theme_options[highlight_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> shark_news_theme_option( 'highlight_title' ),
) );

$wp_customize->add_control( 'shark_news_theme_options[highlight_title]', array(
	'label'             => esc_html__( 'Title', 'shark-news' ),
	'section'           => 'shark_news_highlight_section',
	'type'				=> 'text',
) );

// highlight dot control enable setting and control.
$wp_customize->add_setting( 'shark_news_theme_options[highlight_dot]', array(
	'default'           => shark_news_theme_option('highlight_dot'),
	'sanitize_callback' => 'shark_news_sanitize_switch',
) );

$wp_customize->add_control( new Shark_News_Switch_Control( $wp_customize, 'shark_news_theme_options[highlight_dot]', array(
	'label'             => esc_html__( 'Show Dot Flash', 'shark-news' ),
	'section'           => 'shark_news_highlight_section',
	'on_off_label' 		=> shark_news_show_options(),
) ) );

// highlight arrow control enable setting and control.
$wp_customize->add_setting( 'shark_news_theme_options[highlight_arrow]', array(
	'default'           => shark_news_theme_option('highlight_arrow'),
	'sanitize_callback' => 'shark_news_sanitize_switch',
) );

$wp_customize->add_control( new Shark_News_Switch_Control( $wp_customize, 'shark_news_theme_options[highlight_arrow]', array(
	'label'             => esc_html__( 'Show Arrow Controller', 'shark-news' ),
	'section'           => 'shark_news_highlight_section',
	'on_off_label' 		=> shark_news_show_options(),
) ) );

// highlight auto slide control enable setting and control.
$wp_customize->add_setting( 'shark_news_theme_options[highlight_auto_slide]', array(
	'default'           => shark_news_theme_option('highlight_auto_slide'),
	'sanitize_callback' => 'shark_news_sanitize_switch',
) );

$wp_customize->add_control( new Shark_News_Switch_Control( $wp_customize, 'shark_news_theme_options[highlight_auto_slide]', array(
	'label'             => esc_html__( 'Enable Auto Slide', 'shark-news' ),
	'section'           => 'shark_news_highlight_section',
	'on_off_label' 		=> shark_news_show_options(),
) ) );

// highlight content type control and setting
$wp_customize->add_setting( 'shark_news_theme_options[highlight_content_type]', array(
	'default'          	=> shark_news_theme_option('highlight_content_type'),
	'sanitize_callback' => 'shark_news_sanitize_select',
) );

$wp_customize->add_control( 'shark_news_theme_options[highlight_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'shark-news' ),
	'section'           => 'shark_news_highlight_section',
	'type'				=> 'select',
	'choices'			=> array( 
		'recent' 	=> esc_html__( 'Recent', 'shark-news' ),
		'category' 	=> esc_html__( 'Category', 'shark-news' ),
	),
) );

// highlight count control and setting
$wp_customize->add_setting( 'shark_news_theme_options[highlight_count]', array(
	'default'          	=> shark_news_theme_option('highlight_count'),
	'sanitize_callback' => 'shark_news_sanitize_number_range',
	'validate_callback' => 'shark_news_validate_highlight_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'shark_news_theme_options[highlight_count]', array(
	'label'             => esc_html__( 'Number of Latest Blog', 'shark-news' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 5. Please refresh the page to see the change.', 'shark-news' ),
	'section'           => 'shark_news_highlight_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 5,
		),
) );

// highlight category drop down chooser control and setting
$wp_customize->add_setting( 'shark_news_theme_options[highlight_content_category]', array(
	'sanitize_callback' => 'shark_news_sanitize_category',
) );

$wp_customize->add_control( new Shark_News_Dropdown_Chosen_Control( $wp_customize, 'shark_news_theme_options[highlight_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'shark-news' ),
	'section'           => 'shark_news_highlight_section',
	'choices'			=> shark_news_category_choices(),
	'active_callback'	=> 'shark_news_highlight_content_category_enable',
) ) );
