<?php
/**
 * Highlight hook
 *
 * @package shark_news
 */

if ( ! function_exists( 'shark_news_add_highlight_section' ) ) :
    /**
    * Add highlight section
    *
    *@since Shark News 1.0.0
    */
    function shark_news_add_highlight_section() {

        // Check if highlight is enabled on frontpage
        $highlight_enable = apply_filters( 'shark_news_section_status', 'enable_highlight', 'highlight_entire_site' );

        if ( ! $highlight_enable )
            return false;

        // Get highlight section details
        $section_details = array();
        $section_details = apply_filters( 'shark_news_filter_highlight_section_details', $section_details );

        if ( empty( $section_details ) ) 
            return;

        // Render highlight section now.
        shark_news_render_highlight_section( $section_details );
    }
endif;
add_action( 'shark_news_primary_content_action', 'shark_news_add_highlight_section', 10 );


if ( ! function_exists( 'shark_news_get_highlight_section_details' ) ) :
    /**
    * highlight section details.
    *
    * @since Shark News 1.0.0
    * @param array $input highlight section details.
    */
    function shark_news_get_highlight_section_details( $input ) {

        // Content type.
        $highlight_content_type  = shark_news_theme_option( 'highlight_content_type' );
        $highlight_count  = 3;
        $content = array();
        switch ( $highlight_content_type ) {

            case 'category':
                $cat_id = shark_news_theme_option( 'highlight_content_category' );
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $highlight_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts' => true,
                    ); 
            break;

            case 'recent':
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $highlight_count ),
                    'ignore_sticky_posts' => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) )
            $input = $content;
       
        return $input;
    }
endif;
// highlight section content details.
add_filter( 'shark_news_filter_highlight_section_details', 'shark_news_get_highlight_section_details' );


if ( ! function_exists( 'shark_news_render_highlight_section' ) ) :
  /**
   * Start highlight section
   *
   * @return string highlight content
   * @since Shark News 1.0.0
   *
   */
   function shark_news_render_highlight_section( $content_details = array() ) {
        if ( empty( $content_details ) )
            return;

        $highlight_content_type  = shark_news_theme_option( 'highlight_content_type' );
        $highlight_control = shark_news_theme_option( 'highlight_arrow' );
        $auto_slide = shark_news_theme_option( 'highlight_auto_slide', false );
        $highlight_dot = shark_news_theme_option( 'highlight_dot' );
        $highlight_title = shark_news_theme_option( 'highlight_title', esc_html__( 'Headline', 'shark-news' ) );
        ?>
    	<div id="headline">
            <div class="wrapper">
                <div class="section-title <?php echo $highlight_dot ? 'dot-enabled' : ''; ?>">
                    <?php if ( $highlight_dot ) : ?>
                        <span class="dot-beep"></span>
                    <?php endif; 
                    echo esc_html( $highlight_title ); ?>
                </div>
                <div class="section-content highlight" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1200, "dots": false, "arrows":<?php echo $highlight_control ? 'true' : 'false'; ?>, "vertical": true, "autoplay": <?php echo $auto_slide ? 'true' : 'false'; ?>, "fade": false, "draggable": true }'>
                    <?php foreach ( $content_details as $content ) : ?>
                        <div class="slide-item">
                            <h6>
                                <a href="<?php echo esc_url( $content['url'] ); ?>">
                                    <?php echo esc_html( $content['title'] ); ?> 
                                </a>
                            </h6>
                        </div><!-- .custom-header-content-wrapper -->
                    <?php endforeach; ?>
                </div><!-- .wrapper -->
            </div><!-- .banner-highlight -->
        </div><!-- #custom-header -->
    <?php 
    }
endif;