<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package shark_news
 */

if ( ! function_exists( 'shark_news_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function shark_news_posted_on( $post_id = '' ) {
		$post_id = ! empty( $post_id ) ? $post_id : get_the_id();

		if ( shark_news_meta_option( 'show_date', 'show_single_date' ) ) :
			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
			if ( get_the_time( 'U', $post_id ) !== get_the_modified_time( 'U', $post_id ) ) {
				$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
			}

			$time_string = sprintf( $time_string,
				get_the_date( DATE_W3C, $post_id ),
				get_the_date( '', $post_id ),
				get_the_modified_date( DATE_W3C, $post_id ),
				get_the_modified_date( '', $post_id )
			);
			$year = get_the_date( 'Y' );
			$month = get_the_date( 'm' );
			$link = ( is_single() ) ? get_month_link( $year, $month ) : get_permalink();

			$posted_on = '<a href="' . esc_url( $link ) . '" rel="bookmark">'. shark_news_get_svg( array( 'icon'=> 'clock' ) ) . ' ' . $time_string . '</a>';

			echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.
		endif;
	}
endif;

if ( ! function_exists( 'shark_news_human_time' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function shark_news_human_time( $post_id = '' ) {
		$post_id = ! empty( $post_id ) ? $post_id : get_the_id();
		if ( 'human_time_diff' == shark_news_theme_option( 'homepage_date_format', 'human_time_diff' ) ) :
			printf( '<span class="posted-on"><a href="%1$s">%2$s %3$s</a></span>', get_permalink( $post_id ), shark_news_get_svg( array( 'icon'=> 'clock' ) ), human_time_diff( get_the_date('U', $post_id ), current_time('timestamp') ) . esc_html__( ' ago', 'shark-news' ) );
		else:
			shark_news_posted_on( $post_id );
		endif;
	}
endif;

if ( ! function_exists( 'shark_news_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function shark_news_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			if ( shark_news_meta_option( 'show_category', 'show_single_category' ) ) :
				/* translators: used between list items, there is a space after the comma */
				$categories_list = get_the_category_list( esc_html__( ', ', 'shark-news' ) );
				if ( $categories_list ) {
					/* translators: 1: list of categories. */
					printf( '<span class="cat-links">%1$s %2$s</span>', esc_html__( 'Category:', 'shark-news' ), $categories_list ); // WPCS: XSS OK.
				}
			endif;

			if ( is_single() && shark_news_meta_option( '', 'show_single_tags' ) ) :
				/* translators: used between list items, there is a space after the comma */
				$tags_list = get_the_tag_list();
				if ( $tags_list ) {
					/* translators: 1: list of tags. */
					printf( '<span class="tags-links">%1$s %2$s</span>', esc_html__( 'Tag:', 'shark-news' ), $tags_list ); // WPCS: XSS OK.
				}
			endif;
		}

		if ( shark_news_meta_option( 'show_author', 'show_single_author' ) ) :
			$byline = sprintf(
				/* translators: %s: post author. */
				esc_html_x( ' by %s', 'post author', 'shark-news' ),
				'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
			);
			echo '<span class="byline"> ' . $byline . '</span>';
		endif;

		if ( shark_news_meta_option( 'show_comment', '' ) ) :
			if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
				echo '<span class="comments-link">';
				comments_popup_link(
					sprintf(
						wp_kses(
							/* translators: %s: post title */
							__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'shark-news' ),
							array(
								'span' => array(
									'class' => array(),
								),
							)
						),
						get_the_title()
					)
				);
				echo '</span>';
			}
		endif;

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'shark-news' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

/**
 * Checks to see if meta option is enabled in archive/blog and single
 */
function shark_news_meta_option( $blog_option = '', $single_option = '' ) {
	if ( is_archive() || is_search() || is_home() ) :
		if ( shark_news_theme_option( $blog_option ) )
			return true;
		else
			return false;
	elseif ( is_single() ) :
		if ( shark_news_theme_option( $single_option ) )
			return true;
		else
			return false;
	else :
		return true;
	endif;
}