<?php
/**
 * Category Widget
 *
 * @package shark_news
 */

if ( ! class_exists( 'Shark_News_Category_Widget' ) ) :

     
    class Shark_News_Category_Widget extends WP_Widget {
        /**
         * Sets up the widgets name etc
         */
        public function __construct() {
            $st_widget_category = array(
                'classname'   => 'category_widget',
                'description' => esc_html__( 'Compatible Area: Homepage, Sidebar, Footer', 'shark-news' ),
            );
            parent::__construct( 'shark_news_category_widget', esc_html__( 'ST: Category Widget', 'shark-news' ), $st_widget_category );
        }

        /**
         * Outputs the content of the widget
         *
         * @param array $args
         * @param array $instance
         */
        public function widget( $args, $instance ) {
            // outputs the content of the widget
            if ( ! isset( $args['widget_id'] ) ) {
                $args['widget_id'] = $this->id;
            }

            $count   = isset( $instance['count'] ) ? $instance['count'] : 3;
            $column  = isset( $instance['column'] ) ? $instance['column'] : 'column-2';
            $cat_ids = ! empty( $instance['cat_ids'] ) ? $instance['cat_ids'] : array();
            $content_details = array();

            echo $args['before_widget'];
            ?>
                <div class="featured-categories page-section relative <?php echo esc_attr( $column ); ?>">

                    <div class="content-wrapper">

                        <?php foreach ( $cat_ids as $cat_id ) : ?>
                            <div class="featured-categories-wrapper section-content">

                                <?php $query_args = array(
                                    'post_type'         => 'post',
                                    'posts_per_page'    => absint( $count ),
                                    'cat'               => absint( $cat_id ),
                                    'ignore_sticky_posts' => true,
                                    ); ?>

                                <h3 class="category-title widget-title"><?php echo esc_html( get_cat_name( $cat_id ) ); ?></h3>

                                <?php $query = new WP_Query( $query_args );
                                if ( $query -> have_posts() ) : 
                                    $i = 1;
                                    while ( $query -> have_posts() ) : $query -> the_post(); 
                                        $image_size = $i == 1 ? 'post-thumbnail' : 'thumbnail'; ?>
                                        <article class="hentry <?php echo $i == 1 ? 'full-width' : 'half-width'; ?>">
                                            <div class="post-wrapper">
                                                <?php if ( has_post_thumbnail() ) : ?>
                                                    <div class="featured-image">
                                                        <a href="<?php the_permalink(); ?>">
                                                            <?php the_post_thumbnail( $image_size, array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
                                                        </a>
                                                        <?php if ( 1 == $i ) : 
                                                            shark_news_human_time(); 
                                                        endif; ?>
                                                    </div><!-- .recent-image -->
                                                <?php endif; ?>

                                                <div class="entry-container">
                                                    <header class="entry-header">
                                                        <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>

                                                        <?php if ( 1 !== $i ) :
                                                            shark_news_human_time(); 
                                                        endif; ?>
                                                    </header>

                                                    <?php if ( 1 == $i ) : ?>
                                                        <div class="entry-content">
                                                            <?php echo esc_html( shark_news_trim_content( absint( 15 ) ) ); ?>
                                                        </div><!-- .entry-content -->
                                                    <?php endif; ?>
                                                </div><!-- .entry-container -->
                                            </div><!-- .post-wrapper -->
                                        </article>
                                    <?php $i++; endwhile; 
                                endif;
                                wp_reset_postdata(); ?>

                            </div><!-- .section-content -->
                        <?php endforeach; ?>
                    </div><!-- .content-wrapper -->
                </div><!-- .featured-categories -->

            <?php echo $args['after_widget'];
        }

        /**
         * Outputs the options form on admin
         *
         * @param array $instance The widget options
         */
        public function form( $instance ) {
            $count      = isset( $instance['count'] ) ? $instance['count'] : 3;
            $column     = isset( $instance['column'] ) ? $instance['column'] : 'column-2';
            $cat_ids     = isset( $instance['cat_ids'] ) ? $instance['cat_ids'] : array();
            $category_options = shark_news_category_choices();
            $column_options = array(
                'column-1'  => esc_html__( 'One Column', 'shark-news' ),
                'column-2'  => esc_html__( 'Two Column', 'shark-news' ),
            );
            ?>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'column' ) ); ?>"><?php esc_html_e( 'Column Layout', 'shark-news' ); ?></label>
                <select class="widfat" id="<?php echo esc_attr( $this->get_field_id( 'column' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'column' ) ); ?>" style="width:100%">
                    <?php foreach ( $column_options as $key => $value ) : ?>
                        <option value="<?php echo esc_attr( $key ); ?>" <?php selected( $column, $key, $echo = true ) ?> ><?php echo esc_html( $value ); ?></option>
                    <?php endforeach; ?>
                </select>
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'count' ) ); ?>"><?php esc_html_e( 'No of Posts per Category:', 'shark-news' ); ?></label>
                <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('count') ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'count' ) ); ?>" type="number" min="2" max="6" value="<?php echo absint( $count ); ?>" />
                <small><?php esc_html_e( 'Note: Min 2 & Max 6. Please save the settings to see the change.', 'shark-news' ); ?></small>
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'cat_ids' ) ); ?>"><?php echo esc_html__( 'Select Categories', 'shark-news' ); ?></label>
                <select multiple class="shark-news-widget-chosen-select widfat" id="<?php echo esc_attr( $this->get_field_id( 'cat_ids' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'cat_ids[]' ) ); ?>">
                    <?php $i = 0; foreach ( $category_options as $category_option => $value ) : ?>
                        <option value="<?php echo absint( $category_option ); ?>" <?php echo in_array( $category_option, $cat_ids ) ? 'selected' : ''; ?> ><?php echo esc_html( $value ); ?></option>
                    <?php $i++; endforeach; ?>
                </select>
                <small><?php esc_html_e( 'Note: Only two categories are allowed. Latest four posts will be shown from selected categories.', 'shark-news' ); ?></small>
            </p>

        <?php }

        /**
        * Processing widget options on save
        *
        * @param array $new_instance The new options
        * @param array $old_instance The previous options
        */
        public function update( $new_instance, $old_instance ) {
            // processes widget options to be saved
            $instance                   = $old_instance;
            $instance['count']          = absint( $new_instance['count'] );
            $instance['column']         = sanitize_key( $new_instance['column'] );  
            $new_instance['cat_ids']    = array_slice( $new_instance['cat_ids'], 0, 2 );
            $instance['cat_ids']        = shark_news_sanitize_category_list( $new_instance['cat_ids'] );
           
            return $instance;
        }
    }
endif;
